netapp_ontap.models.snapmirror_transfer_relationship API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snapmirror_transfer_relationship`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnapmirrorTransferRelationshipSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapmirrorTransferRelationship object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `destination GET POST PATCH`

    The destination field of the snapmirror_transfer_relationship.

  `restore GET POST PATCH`

    Is the relationship for restore?

  `uuid GET POST PATCH`

    The uuid field of the snapmirror_transfer_relationship.

    Example: d2d7ceea-ab52-11e8-855e-00505682a4c7